/*
 * Licensed Materials - Property of Perforce Software, Inc. 
 * © Copyright Perforce Software, Inc. 2014, 2021 
 * © Copyright IBM Corp. 2009, 2014
 * © Copyright ILOG 1996, 2009
 * All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * The Software and Documentation were developed at private expense and
 * are "Commercial Items" as that term is defined at 48 CFR 2.101,
 * consisting of "Commercial Computer Software" and
 * "Commercial Computer Software Documentation", as such terms are
 * used in 48 CFR 12.212 or 48 CFR 227.7202-1 through 227.7202-4,
 * as applicable.
 */

// the Perforce JViews Diagrammer Framework
// the Java AWT package
import java.awt.Container;

// the Java Swing package
import javax.swing.SwingUtilities;

// the Perforce JViews Diagrammer Framework
import ilog.views.diagrammer.application.IlvDiagrammerAction;
import ilog.views.diagrammer.application.IlvDiagrammerFrame;
import ilog.views.diagrammer.application.IlvDiagrammerMenuBar;
import ilog.views.diagrammer.application.IlvDiagrammerToolBar;
import ilog.views.util.IlvProductUtil;

/**
 * A very simple example for the use of a Layout Algorithm. It shows how to use
 * graph layout directly with a diagram component. It loads a idpr project that
 * specifies which CSS style sheet and which XML data file should be loaded. The
 * layout is fully specified in this style sheet. It uses the functionality of
 * IlvDiagrammerApplication to add the default layout buttons.
 */
public class Sample1a extends IlvDiagrammerFrame {
  private static final String graphLayoutProject = "data/Sample.idpr";

  public static void main(final String[] args) {
    // This sample uses JViews Diagrammer features. When deploying an
    // application that includes this code, you need to be in possession
    // of a Perforce JViews Diagrammer Deployment license.
    IlvProductUtil.DeploymentLicenseRequired(IlvProductUtil.JViews_Diagrammer_Deployment);

    SwingUtilities.invokeLater(new Runnable() {
      @Override
      public void run() {
        new Sample1a().init(args);

      }
    });
  }

  public Sample1a() {
    super(
        new String[] { "-title", "Graph Layout Diagrammer Demo - Link Layout", "-data", graphLayoutProject, "-edit" });
  }

  @Override
  public void init(Container contentPane) {
    super.init(contentPane);

    getJMenuBar().remove(((IlvDiagrammerMenuBar) getJMenuBar()).getFileMenu());
    getJMenuBar().remove(((IlvDiagrammerMenuBar)getJMenuBar()).getEditMenu());
    getJMenuBar().remove(((IlvDiagrammerMenuBar)getJMenuBar()).getOptionsMenu());

    IlvDiagrammerToolBar toolbar = getEditToolBar();

    toolbar.setActions(null);

    toolbar.addAction(IlvDiagrammerAction.layoutAllNodes);

    // Could be enabled to have an action that allows to layout selected nodes
    // toolbar.addAction(IlvDiagrammerAction.layoutSelectedNodes);
  }
}
